@@ -40,7 +40,7 @@ else:
     from urllib import parse, request
 
 # Version Python-Acapela
-__version__ = '0.2.2'
+__version__ = '0.2.4'
 
 ACCOUNT_LOGIN = 'EVAL_XXXX'
 APPLICATION_LOGIN = 'EVAL_XXXXXXX'
@@ -93,8 +93,8 @@ class Acapela(object):
     # http://www.acapela-vaas.com/ReleasedDocumentation/voices_list.php
 
     langs = {
-        'EN': {'W': {'NORMAL': 'rachel'}, 'M': {'NORMAL': 'margaux'}},
-        'US': {'W': {'NORMAL': 'heather'}, 'M': {'NORMAL': 'ryan'}},
+        'EN': {'W': {'NORMAL': 'lucy'}, 'M': {'NORMAL': 'graham'}},
+        'US': {'W': {'NORMAL': 'karen'}, 'M': {'NORMAL': 'ryan'}},
         'ES': {'W': {'NORMAL': 'ines'}, 'M': {'NORMAL': 'antonio'}},
         'FR': {'W': {'NORMAL': 'alice'}, 'M': {'NORMAL': 'antoine'}},
         'PT': {'W': {'NORMAL': 'celia'}},
